# GDA Importer

GDA Importer is the default project generated by GDA Cookiecutter. GDA Importer contains all the boilerplate you need to create a Python package according to the best-practices of Geometric Data Analytics, Inc.

See the Documentation at https://geomdata.pages.geomdata.com/gda-importer

## Installation

### Note Possible `conda` Dependencies

Regardless of how you follow the User Installation subsection below, be sure to check if there are any additional, `conda`-specific requirements for the package specified in `environment.yml`.

If there are any dependencies there other than the [cookiecutter defaults](https://gitlab.geomdata.com/geomdata/gda-cookiecutter/-/blob/master/environment.yml?ref_type=heads), then these may be important to include in a working conda environment wherever you intend to use this package. If there are no additional dependencies there, then this step can be disregarded.

### User Installation

If you just want to run the software, do any of these:

- For the official, stable published version, use `pip install gda-importer`

*Internal users* are encouraged to add this dependency to their repository using `private_deps.toml`.  The section name is used for the `pip` call, so it can include optional dependencies too.  For this project, the specification would look like:

```toml
["gda-importer[testing]"]
gitlab_host = "gitlab.geomdata.com"
gitlab_path = "geomdata/gda-importer"
gitlab_spec = "<current stable release>"
```

It is **_strongly encouraged_** for internal users to choose the `<current stable release>` (i.e. `vX.Y.Z`, be sure to include the `v` in the version!) as specified at the top of this repository's [release history](https://gitlab.geomdata.com/geomdata/gda-importer/-/releases). This release can also be found on the "Current Stable Release" badge on the [project home page](https://gitlab.geomdata.com/geomdata/gda-importer).

If working outside of the `private_deps.toml` framework, and you have the necessary https login / ssh keys, the following will also work for installation:
  - `pip install https://gitlab.geomdata.com/geomdata/gda-importer.git@<current stable release>` or
  - `pip install git+ssh://git@gitlab.geomdata.com/geomdata/gda-importer.git@<current stable release>` or
  - `pip install .` assuming you just cloned the repository to the current directory and checked out the desired tag / branch.
- For more advanced or customized development options, as well as developer installation instructions, see [CONTRIBUTING.md](CONTRIBUTING.md) and [DEPENDENCIES.md](DEPENDENCIES.md).

## Features

* pip installable
* testing suite with pytest
* documentation with quartodoc
* tests and deployment integrated with gitlab CI/CD

## Credits

This package was initialized with cookiecutter and the `GDA Cookiecutter` project template.

* [GDA Cookiecutter](https://gitlab.geomdata.com/geomdata/gda-cookiecutter/)
* [example Python Boilerplate](https://gitlab.geomdata.com/geomdata/python-boilerplate)
* [Cookiecutter](https://github.com/audreyr/cookiecutter)
